@@ -66,6 +66,7 @@ void TaskPanel::initWayland()
     }
     using namespace KWayland::Client;
     ConnectionThread *connection = ConnectionThread::fromApplication(this);
+
     if (!connection) {
         return;
     }
@@ -90,7 +91,7 @@ void TaskPanel::initWayland()
             connect(m_windowManagement, &KWayland::Client::PlasmaWindowManagement::activeWindowChanged,
                     m_activeTimer, qOverload<>(&QTimer::start));
 
-            updateActiveWindow();
+            m_activeTimer->start();
         }
     );
     connect(registry, &Registry::plasmaShellAnnounced, this,
@@ -170,6 +171,17 @@ void TaskPanel::updateActiveWindow()
                 this, &TaskPanel::forgetActiveWindow);
     }
 
+    bool newAllMinimized = true;
+    for (auto *w : m_windowManagement->windows()) {
+        if (!w->isMinimized() && !w->skipTaskbar() && !w->isFullscreen() /*&& w->appId() != QStringLiteral("org.kde.plasmashell")*/) {
+            newAllMinimized = false;
+            break;
+        }
+    }
+    if (newAllMinimized != m_allMinimized) {
+        m_allMinimized = newAllMinimized;
+        emit allMinimizedChanged();
+    }
     // TODO: connect to closeableChanged, not needed right now as KWin doesn't provide this changeable
     emit hasCloseableActiveWindowChanged();
 }
